@@ -1,13 +1,13 @@
 from __future__ import annotations
 
 from asyncio import AbstractEventLoop, get_event_loop
-from typing import Optional
+from typing import Optional, Union
 from urllib.parse import urljoin
 
 import nest_asyncio
 from aiohttp import ClientSession
 
-from terra_sdk.core import Coins, Numeric
+from terra_sdk.core import Coins, Dec, Numeric
 from terra_sdk.exceptions import LCDResponseError
 from terra_sdk.key.key import Key
 from terra_sdk.util.json import dict_to_data
@@ -34,9 +34,9 @@ class AsyncLCDClient:
     def __init__(
         self,
         url: str,
-        chain_id: str = None,
-        gas_prices: Coins.Input = None,
-        gas_adjustment: Numeric.Input = None,
+        chain_id: Optional[str] = None,
+        gas_prices: Optional[Coins.Input] = None,
+        gas_adjustment: Optional[Numeric.Input] = None,
         loop: Optional[AbstractEventLoop] = None,
         _create_session: bool = True,  # don't create a session (used for sync LCDClient)
     ):
@@ -52,7 +52,7 @@ class AsyncLCDClient:
         self.url = url
         self.gas_prices = Coins(gas_prices)
         self.gas_adjustment = gas_adjustment
-        self._last_request_height = None
+        self.last_request_height = None
 
         self.auth = AsyncAuthAPI(self)
         self.bank = AsyncBankAPI(self)
@@ -71,6 +71,11 @@ class AsyncLCDClient:
         self.tx = AsyncTxAPI(self)
 
     def wallet(self, key: Key) -> AsyncWallet:
+        """Creates a :class:`AsyncWallet` object from a key.
+
+        Args:
+            key (Key): key implementation
+        """
         return AsyncWallet(self, key)
 
     async def _get(
@@ -79,13 +84,13 @@ class AsyncLCDClient:
         async with self.session.get(
             urljoin(self.url, endpoint), params=params
         ) as response:
-            result = await response.json()
+            result = await response.json(content_type=None)
             if not str(response.status).startswith("2"):
                 raise LCDResponseError(message=result.get("error"), response=response)
         try:
-            self._last_request_height = result["height"]
+            self.last_request_height = result["height"]
         except KeyError:
-            self._last_request_height = None
+            self.last_request_height = None
         return result if raw else result["result"]
 
     async def _post(
@@ -94,13 +99,13 @@ class AsyncLCDClient:
         async with self.session.post(
             urljoin(self.url, endpoint), json=data and dict_to_data(data)
         ) as response:
-            result = await response.json()
+            result = await response.json(content_type=None)
             if not str(response.status).startswith("2"):
                 raise LCDResponseError(message=result.get("error"), response=response)
         try:
-            self._last_request_height = result["height"]
+            self.last_request_height = result["height"]
         except KeyError:
-            self._last_request_height = None
+            self.last_request_height = None
         return result if raw else result["result"]
 
     async def __aenter__(self):
@@ -111,13 +116,83 @@ class AsyncLCDClient:
 
 
 class LCDClient(AsyncLCDClient):
-    def __init__(self, *args, **kwargs):
-        options = {
-            **kwargs,
-            "_create_session": False,
-            "loop": nest_asyncio.apply(get_event_loop()),
-        }
-        super().__init__(*args, **options)
+    """An object representing a connection to a node running the Terra LCD server."""
+
+    url: str
+    """URL endpoint of LCD server."""
+
+    chain_id: str
+    """Chain ID of blockchain network connecting to."""
+
+    gas_prices: Coins
+    """Gas prices to use for automatic fee estimation."""
+
+    gas_adjustment: Union[str, float, int, Dec]
+    """Gas adjustment factor for automatic fee estimation."""
+
+    last_request_height: Optional[int]  # type: ignore
+    """Height of response of last-made made LCD request."""
+
+    auth: AuthAPI
+    """:class:`AuthAPI<terra_sdk.client.lcd.api.auth.AuthAPI>`."""
+
+    bank: BankAPI
+    """:class:`BankAPI<terra_sdk.client.lcd.api.bank.BankAPI>`."""
+
+    distribution: DistributionAPI
+    """:class:`DistributionAPI<terra_sdk.client.lcd.api.distribution.DistributionAPI>`."""
+
+    gov: GovAPI
+    """:class:`GovAPI<terra_sdk.client.lcd.api.gov.GovAPI>`."""
+
+    market: MarketAPI
+    """:class:`MarketAPI<terra_sdk.client.lcd.api.market.MarketAPI>`."""
+
+    mint: MintAPI
+    """:class:`MintAPI<terra_sdk.client.lcd.api.mint.MintAPI>`."""
+
+    msgauth: MsgAuthAPI
+    """:class:`MsgAuthAPI<terra_sdk.client.lcd.api.msgauth.MsgAuthAPI>`."""
+
+    oracle: OracleAPI
+    """:class:`OracleAPI<terra_sdk.client.lcd.api.oracle.OracleAPI>`."""
+
+    slashing: SlashingAPI
+    """:class:`SlashingAPI<terra_sdk.client.lcd.api.slashing.SlashingAPI>`."""
+
+    staking: StakingAPI
+    """:class:`StakingAPI<terra_sdk.client.lcd.api.staking.StakingAPI>`."""
+
+    supply: SupplyAPI
+    """:class:`SupplyAPI<terra_sdk.client.lcd.api.supply.SupplyAPI>`."""
+
+    tendermint: TendermintAPI
+    """:class:`TendermintAPI<terra_sdk.client.lcd.api.tendermint.TendermintAPI>`."""
+
+    treasury: TreasuryAPI
+    """:class:`TreasuryAPI<terra_sdk.client.lcd.api.treasury.TreasuryAPI>`."""
+
+    wasm: WasmAPI
+    """:class:`WasmAPI<terra_sdk.client.lcd.api.wasm.WasmAPI>`."""
+
+    tx: TxAPI
+    """:class:`TxAPI<terra_sdk.client.lcd.api.tx.TxAPI>`."""
+
+    def __init__(
+        self,
+        url: str,
+        chain_id: str = None,
+        gas_prices: Optional[Coins.Input] = None,
+        gas_adjustment: Optional[Numeric.Input] = None,
+    ):
+        super().__init__(
+            url,
+            chain_id,
+            gas_prices,
+            gas_adjustment,
+            _create_session=False,
+            loop=nest_asyncio.apply(get_event_loop()),
+        )
 
         self.auth = AuthAPI(self)
         self.bank = BankAPI(self)
@@ -146,6 +221,12 @@ class LCDClient(AsyncLCDClient):
         )
 
     def wallet(self, key: Key) -> Wallet:  # type: ignore
+        """Creates a :class:`Wallet` object from a key for easy transaction creating and
+        signing.
+
+        Args:
+            key (Key): key implementation
+        """
         return Wallet(self, key)
 
     async def _get(self, *args, **kwargs):
