@@ -27,7 +27,8 @@ class AsyncWallet:
         return await self.lcd.tx.create(self.key.acc_address, *args, **kwargs)
 
     async def create_and_sign_tx(self, *args, **kwargs) -> StdTx:
-        return self.key.sign_tx(await self.create_tx(*args, **kwargs))
+        tx = await self.create_tx(*args, **kwargs)
+        return self.key.sign_tx(tx)
 
 
 class Wallet:
