@@ -8,9 +8,10 @@ import attr
 
 from terra_sdk.core.coins import Coins
 from terra_sdk.core.msg import Msg
-from terra_sdk.core.public_key import PublicKey
 from terra_sdk.util.json import JSONSerializable
 
+from .public_key import PublicKey
+
 __all__ = [
     "StdSignature",
     "StdFee",
@@ -24,9 +25,13 @@ __all__ = [
 
 @attr.s
 class StdSignature(JSONSerializable):
+    """Data structure holding information for a transaction signature."""
 
     signature: str = attr.ib()
+    """Actual signature contents."""
+
     pub_key: Optional[PublicKey] = attr.ib()
+    """Signature's public key information."""
 
     @classmethod
     def from_data(cls, data: dict) -> StdSignature:
@@ -38,6 +43,12 @@ class StdSignature(JSONSerializable):
 
 @attr.s
 class StdFee(JSONSerializable):
+    """Data structure holding information for a transaction fee.
+
+    Args:
+        gas (int): gas to use ("gas requested")
+        amount (Coins.Input): fee amount
+    """
 
     gas: int = attr.ib(converter=int)
     amount: Coins = attr.ib(converter=Coins)
@@ -56,6 +67,19 @@ class StdFee(JSONSerializable):
 
 @attr.s
 class StdSignMsg(JSONSerializable):
+    """Data structure holding information which can be signed to create a :class:`StdTx`.
+
+    .. note::
+        This object can be considered an "unsigned transaction".
+
+    Args:
+        chain_id (str): chain ID
+        account_number (int): account number
+        sequence (int): sequence number
+        fee (StdFee): transaction fee
+        msgs (List[Msg]): list of messages to include
+        memo (str): transaction memo
+    """
 
     chain_id: str = attr.ib()
     account_number: int = attr.ib(converter=int)
@@ -91,6 +115,14 @@ class StdSignMsg(JSONSerializable):
 
 @attr.s
 class StdTx(JSONSerializable):
+    """Data structure for a transaction which can be broadcasted.
+
+    Arg:
+        msg: list of messages to include in transaction
+        fee: fee to use for transaction
+        signatures: list of signatures
+        memo: transaction memo
+    """
 
     msg: List[Msg] = attr.ib()
     fee: StdFee = attr.ib()
@@ -133,11 +165,27 @@ def parse_events_by_type(event_data: List[dict]) -> Dict[str, Dict[str, List[str
 
 @attr.s
 class TxLog(JSONSerializable):
+    """Object containing the events of a transaction that is automatically generated when
+    :class:`TxInfo` or :class:`BlockTxBroadcastResult` objects are read."""
 
     msg_index: int = attr.ib(converter=int)
+    """Number of the message inside the transaction that it was included in."""
+
     log: str = attr.ib()
+    """This field may be populated with details of the message's error, if any."""
+
     events: List[dict] = attr.ib()
+    """Raw event log data"""
+
     events_by_type: Dict[str, Dict[str, List[str]]] = attr.ib(init=False)
+    """Event log data, re-indexed by event type name and attribute type.
+
+    For instance, the event type may be: ``store_code`` and an attribute key could be
+    ``code_id``.
+
+    >>> logs[0].events_by_type["<event-type>"]["<attribute-key>"]
+    ['<attribute-value>', '<attribute-value2>']
+    """
 
     def __attrs_post_init__(self):
         self.events_by_type = parse_events_by_type(self.events)
@@ -156,17 +204,43 @@ def parse_tx_logs(logs) -> Optional[List[TxLog]]:
 
 @attr.s
 class TxInfo(JSONSerializable):
+    """Holds information pertaining to a transaction which has been included in a block
+    on the blockchain.
+
+    .. note::
+        Users are not expected to create this object directly. It is returned by
+        :meth:`TxAPI.tx_info()<terra_sdk.client.lcd.api.tx.TxAPI.tx_info>`
+    """
 
     height: int = attr.ib(converter=int)
+    """Block height at which transaction was included."""
+
     txhash: str = attr.ib()
+    """Transaction hash."""
+
     rawlog: str = attr.ib()
+    """Event log information as a raw JSON-string."""
+
     logs: Optional[List[TxLog]] = attr.ib()
+    """Event log information."""
+
     gas_wanted: int = attr.ib(converter=int)
+    """Gas requested by transaction."""
+
     gas_used: int = attr.ib(converter=int)
+    """Actual gas amount used."""
+
     tx: StdTx = attr.ib()
+    """Transaction object."""
+
     timestamp: str = attr.ib()
+    """Time at which transaction was included."""
+
     code: Optional[int] = attr.ib(default=None)
+    """If this field is not ``None``, the transaction failed at ``DeliverTx`` stage."""
+
     codespace: Optional[str] = attr.ib(default=None)
+    """Error subspace (used alongside ``code``)."""
 
     def to_data(self) -> dict:
         data = {
@@ -199,7 +273,7 @@ class TxInfo(JSONSerializable):
             data["height"],
             data["txhash"],
             data["raw_log"],
-            parse_tx_logs(data["logs"]),
+            parse_tx_logs(data.get("logs")),
             data["gas_wanted"],
             data["gas_used"],
             StdTx.from_data(data["tx"]),
