@@ -17,12 +17,19 @@ __all__ = [
 
 @attr.s
 class MsgModifyWithdrawAddress(Msg):
-    """Modify the Withdraw Address of a delegator."""
+    """Modify the Withdraw Address of a delegator.
+
+    Args:
+        delegator_address: delegator
+        withdraw_address: new withdraw address
+    """
 
     type = "distribution/MsgModifyWithdrawAddress"
+    """"""
     action = "set_withdraw_address"
+    """"""
 
-    delegator_address: AccAddress = attr.ib()  # hello
+    delegator_address: AccAddress = attr.ib()
     withdraw_address: AccAddress = attr.ib()
 
     @classmethod
@@ -36,10 +43,17 @@ class MsgModifyWithdrawAddress(Msg):
 
 @attr.s
 class MsgWithdrawDelegationReward(Msg):
-    """Withdraw rewards for a delegation specified by a (delegator, validator) pair."""
+    """Withdraw rewards for a delegation specified by a (delegator, validator) pair.
+
+    Args:
+        delegator_address: delegator
+        validator_address: validator
+    """
 
     type = "distribution/MsgWithdrawDelegationReward"
+    """"""
     action = "withdraw_delegation_reward"
+    """"""
 
     delegator_address: AccAddress = attr.ib()
     validator_address: ValAddress = attr.ib()
@@ -55,10 +69,16 @@ class MsgWithdrawDelegationReward(Msg):
 
 @attr.s
 class MsgWithdrawValidatorCommission(Msg):
-    """Withdraw rewards accrued for a validator gained through commissions."""
+    """Withdraw rewards accrued for a validator gained through commissions.
+
+    Args:
+        validator_address: validator operator address
+    """
 
     type = "distribution/MsgWithdrawValidatorCommission"
+    """"""
     action = "withdraw_validator_commission"
+    """"""
 
     validator_address: ValAddress = attr.ib()
 
@@ -70,9 +90,15 @@ class MsgWithdrawValidatorCommission(Msg):
 
 @attr.s
 class MsgFundCommunityPool(Msg):
-    """Deposit assets to the Community Pool."""
+    """Deposit assets to the Community Pool.
+
+    Args:
+        depositor (AccAddress): sender
+        amount (Coins): amount to fund community pool with
+    """
 
     type = "distribution/MsgFundCommunityPool"
+    """"""
 
     depositor: AccAddress = attr.ib()
     amount: Coins = attr.ib(converter=Coins)
