@@ -12,9 +12,17 @@ __all__ = ["CommunityPoolSpendProposal"]
 
 @attr.s
 class CommunityPoolSpendProposal(Content):
-    """Proposal for allocating funds from the community pool to an address."""
+    """Proposal for allocating funds from the community pool to an address.
+
+    Args:
+        title: proposal title
+        description: proposal description
+        recipient: designated recipient of funds if proposal passes
+        amount (Coins): amount to spend from community pool
+    """
 
     type = "distribution/CommunityPoolSpendProposal"
+    """"""
 
     title: str = attr.ib()
     description: str = attr.ib()
