@@ -1,14 +1,20 @@
+"""Numeric types."""
+
 from __future__ import annotations
 
 import re
 from decimal import Decimal
 from typing import Union
 
+from terra_sdk.util.json import JSONSerializable
+
 DEC_NUM_DIGITS = 18
+"""Number of digits for Decimal."""
+
 DEC_ONE = 10 ** DEC_NUM_DIGITS
 DEC_PATTERN = re.compile(r"^(\-)?(\d+)(\.(\d+))?\Z")
 
-__all__ = ["DEC_NUM_DIGITS", "Dec"]
+__all__ = ["DEC_NUM_DIGITS", "Dec", "Numeric"]
 
 
 def convert_to_dec_bignum(arg: Union[str, int, float, Decimal]):
@@ -59,16 +65,26 @@ def chop_precision_and_round(d: int) -> int:
         return quo + 1
 
 
-class Dec:
+class Dec(JSONSerializable):
+    """BigInt-based Decimal representation with basic arithmetic operations with
+    compatible Python numeric types (int, float, Decimal). Does not work with
+    ``NaN``, ``Infinity``, ``+0``, ``-0``, etc. Serializes as a string with 18 points of
+    decimal precision.
+
+    >>> Dec(5)
+    Dec("5.0")
+    >>> Dec("121.1232")
+    Dec("121.1232")
+    >>> Dec(121.1232)
+    Dec("121.1232")
+
+    Args:
+        arg (Union[str, int, float, Decimal, Dec]): argument to coerce into Dec
+    """
 
     _i: int = 0
 
     def __init__(self, arg: Union[str, int, float, Decimal, Dec]):
-        """BigInt-based Decimal representation with basic arithmetic operations with
-        compatible Python numeric types (int, float, Decimal). Does not work with
-        NaN, Infinity, +0, -0, etc. Serializes as a string with 18 points of decimal
-        DEC_NUM_DIGITS.
-        """
         if isinstance(arg, Dec):
             self._i = arg._i
             return
@@ -76,22 +92,42 @@ class Dec:
             self._i = int(convert_to_dec_bignum(arg))
 
     @classmethod
-    def zero(cls):
+    def zero(cls) -> Dec:
+        """Dec representation of zero.
+
+        Returns:
+            Dec: zero
+        """
         return cls(0)
 
     @classmethod
     def one(cls):
+        """Dec representation of one.
+
+        Returns:
+            Dec: one
+        """
         nd = cls(0)
         nd._i = DEC_ONE
         return nd
 
     def __str__(self) -> str:
+        """Converts to a string using all 18 decimal precision points.
+
+        Returns:
+            str: string representation
+        """
         if self._i == 0:
             return "0." + DEC_NUM_DIGITS * "0"
         parity = "-" if self._i < 0 else ""
         return f"{parity}{self.whole}.{self.frac}"
 
-    def to_short_str(self):
+    def to_short_str(self) -> str:
+        """Converts to a string, but truncates all unnecessary zeros.
+
+        Returns:
+            str: string representation
+        """
         parity = "-" if self._i < 0 else ""
         frac = self.frac.rstrip("0")
         dot = "." if len(frac) > 0 else ""
@@ -112,14 +148,29 @@ class Dec:
 
     @property
     def parity(self) -> int:
+        """Get the parity of the Dec value. Returns -1 if value is below 0, and 1 otherwise.
+
+        Returns:
+            int: parity
+        """
         return -1 if self._i < 0 else 1
 
     @property
     def whole(self) -> str:
+        """Get the integral part of the Dec value.
+
+        Returns:
+            str: integer, as string
+        """
         return str(abs(self._i) // DEC_ONE)
 
     @property
     def frac(self) -> str:
+        """Get the fractional part of the Dec value.
+
+        Returns:
+            str: fraction, as string
+        """
         return str(abs(self._i) % DEC_ONE).rjust(DEC_NUM_DIGITS, "0")
 
     def to_data(self) -> str:
@@ -131,21 +182,36 @@ class Dec:
         else:
             return self._i == Dec(other)._i
 
-    def lt(self, other) -> bool:
+    def lt(self, other: Union[str, int, float, Decimal, Dec]) -> bool:
+        """Check less than.
+
+        Args:
+            other (Union[str, int, float, Decimal, Dec]): compared object
+        """
         if isinstance(other, Dec):
             return self._i < other._i
         return (Decimal(self._i) / DEC_ONE) < other
 
-    def __lt__(self, other) -> bool:
+    def __lt__(self, other: Union[str, int, float, Decimal, Dec]) -> bool:
         return self.lt(other)
 
-    def le(self, other) -> bool:
+    def le(self, other: Union[str, int, float, Decimal, Dec]) -> bool:
+        """Check less than or equal to.
+
+        Args:
+            other (Union[str, int, float, Decimal, Dec]): compared object
+        """
         return self < other or self.__eq__(other)
 
-    def __le__(self, other) -> bool:
+    def __le__(self, other: Union[str, int, float, Decimal, Dec]) -> bool:
         return self.le(other)
 
-    def gt(self, other) -> bool:
+    def gt(self, other: Union[str, int, float, Decimal, Dec]) -> bool:
+        """Check greater than.
+
+        Args:
+            other (Union[str, int, float, Decimal, Dec]): compared object
+        """
         if isinstance(other, Dec):
             return self._i > other._i
         return (Decimal(self._i) / DEC_ONE) > other
@@ -154,67 +220,115 @@ class Dec:
         return self.gt(other)
 
     def ge(self, other) -> bool:
+        """Check greater than or equal to.
+
+        Args:
+            other (Union[str, int, float, Decimal, Dec]): compared object
+        """
         return self.gt(other) or self.__eq__(other)
 
     def __ge__(self, other) -> bool:
         return self.ge(other)
 
-    def add(self, other) -> Dec:
+    def add(self, addend: Union[str, int, float, Decimal, Dec]) -> Dec:
+        """Performs addition. ``addend`` is first converted into Dec.
+
+        Args:
+            addend (Union[str, int, float, Decimal, Dec]): addend
+
+        Returns:
+            Dec: sum
+        """
         nd = Dec.zero()
-        nd._i = self._i + Dec(other)._i
+        nd._i = self._i + Dec(addend)._i
         return nd
 
-    def __add__(self, other) -> Dec:
-        return self.add(other)
+    def __add__(self, addend: Union[str, int, float, Decimal, Dec]) -> Dec:
+        return self.add(addend)
 
-    def __radd__(self, other):
-        return Dec(other).add(self)
+    def __radd__(self, addend: Union[str, int, float, Decimal, Dec]):
+        return Dec(addend).add(self)
 
-    def sub(self, other) -> Dec:
+    def sub(self, subtrahend: Union[str, int, float, Decimal, Dec]) -> Dec:
+        """Performs subtraction. ``subtrahend`` is first converted into Dec.
+
+        Args:
+            subtrahend (Union[str, int, float, Decimal, Dec]): subtrahend
+
+        Returns:
+            Dec: difference
+        """
         nd = Dec.zero()
-        nd._i = self._i - Dec(other)._i
+        nd._i = self._i - Dec(subtrahend)._i
         return nd
 
-    def __sub__(self, other) -> Dec:
-        return self.sub(other)
+    def __sub__(self, subtrahend: Union[str, int, float, Decimal, Dec]) -> Dec:
+        return self.sub(subtrahend)
 
-    def __rsub__(self, other):
-        return Dec(other).sub(self)
+    def __rsub__(self, minuend: Dec) -> Dec:
+        return Dec(minuend).sub(self)
 
-    def mul(self, other: Union[str, int, float, Decimal, Dec]) -> Dec:
+    def mul(self, multiplier: Union[str, int, float, Decimal, Dec]) -> Dec:
+        """Performs multiplication. ``multiplier`` is first converted into Dec.
+
+        Args:
+            multiplier (Union[str, int, float, Decimal, Dec]): multiplier
+
+        Returns:
+            Dec: product
+        """
         x = self._i
-        y = Dec(other)._i
+        y = Dec(multiplier)._i
         nd = Dec.zero()
         nd._i = chop_precision_and_round(x * y)
         return nd
 
-    def __mul__(self, other) -> Dec:
-        return self.mul(other)
+    def __mul__(self, multiplier: Union[str, int, float, Decimal, Dec]) -> Dec:
+        return self.mul(multiplier)
 
-    def __rmul__(self, other):
-        return Dec(other).mul(self)
+    def __rmul__(self, multiplicand: Union[str, int, float, Decimal, Dec]):
+        return Dec(multiplicand).mul(self)
 
-    def div(self, other) -> Dec:
-        if Dec(other)._i == 0:
-            raise ZeroDivisionError(f"tried to divide by 0: {self!r} / {other!r}")
+    def div(self, divisor: Union[str, int, float, Decimal, Dec]) -> Dec:
+        """Performs division. ``divisor`` is first converted into Dec.
+
+        Args:
+            divisor (Union[str, int, float, Decimal, Dec]): divisor
+
+        Raises:
+            ZeroDivisionError: if ``divisor`` is 0
+
+        Returns:
+            Dec: quotient
+        """
+        if Dec(divisor)._i == 0:
+            raise ZeroDivisionError(f"tried to divide by 0: {self!r} / {divisor!r}")
         nd = Dec.zero()
-        nd._i = chop_precision_and_round(self._i * DEC_ONE * DEC_ONE // Dec(other)._i)
+        nd._i = chop_precision_and_round(self._i * DEC_ONE * DEC_ONE // Dec(divisor)._i)
         return nd
 
-    def __truediv__(self, other) -> Dec:
-        return self.div(other)
+    def __truediv__(self, divisor) -> Dec:
+        return self.div(divisor)
 
-    def __rtruediv__(self, other) -> Dec:
-        return Dec(other).div(self)
+    def __rtruediv__(self, divisor) -> Dec:
+        return Dec(divisor).div(self)
 
-    def __floordiv__(self, other):
-        return self.div(int(other))
+    def __floordiv__(self, divisor):
+        return self.div(int(divisor))
 
-    def mod(self, other) -> Dec:
-        return self.sub(self.div(other).mul(self))
+    def mod(self, modulo: Union[str, int, float, Decimal, Dec]) -> Dec:
+        """Performs modulus. ``modulo`` is first converted into Dec.
 
-    def __mod__(self, other) -> Dec:
-        return self.mod(other)
+        Args:
+            modulo (Union[str, int, float, Decimal, Dec]): modulo
+
+        Returns:
+            Dec: modulus
+        """
+        return self.sub(self.div(modulo).mul(self))
+
+    def __mod__(self, modulo) -> Dec:
+        return self.mod(modulo)
 
     def __neg__(self) -> Dec:
         x = Dec(self)
@@ -231,11 +345,20 @@ class Dec:
 
     @classmethod
     def from_data(cls, data: str) -> Dec:
+        """Converts Dec-formatted string into proper :class:`Dec` object."""
         return cls(data)
 
     @classmethod
     def with_prec(cls, i: Union[int, str], prec: int) -> Dec:
-        """Replicates Cosmos-SDK's Dec.with_prec(i, prec)"""
+        """Replicates Cosmos SDK's ``Dec.withPreic(i, prec)``.
+
+        Args:
+            i (Union[int, str]): numeric value
+            prec (int): precision
+
+        Returns:
+            Dec: decimal
+        """
         d = cls(0)
         i = int(i)
         d._i = i * 10 ** (DEC_NUM_DIGITS - int(prec))
@@ -245,10 +368,24 @@ class Dec:
 class Numeric:
 
     Input = Union[str, int, float, Decimal, Dec]
+    """"""
+
     Output = Union[int, Dec]
+    """"""
 
     @staticmethod
     def parse(value: Numeric.Input) -> Numeric.Output:
+        """Parses the value and coerces it into an ``int`` or :class:`Dec`.
+
+        Args:
+            value (Numeric.Input): value to be parsed
+
+        Raises:
+            TypeError: if supplied value could not be parsed
+
+        Returns:
+            Numeric.Output: coerced number
+        """
         if isinstance(value, int) or isinstance(value, Dec):
             return value
         elif isinstance(value, str):
