@@ -1,3 +1,5 @@
+"""Treasury module governance proposals."""
+
 from __future__ import annotations
 
 import attr
@@ -10,8 +12,16 @@ __all__ = ["TaxRateUpdateProposal", "RewardWeightUpdateProposal"]
 
 @attr.s
 class TaxRateUpdateProposal(Content):
+    """Proposal to adjust the protocol-level tax rate.
+
+    Args:
+        title: proposal title
+        description: proposal description
+        tax_rate (Dec): new proposed tax rate
+    """
 
     type = "treasury/TaxRateUpdateProposal"
+    """"""
 
     title: str = attr.ib()
     description: str = attr.ib()
@@ -29,8 +39,16 @@ class TaxRateUpdateProposal(Content):
 
 @attr.s
 class RewardWeightUpdateProposal(Content):
+    """Proposal to adjust the protocol-level reward weight.
+
+    Args:
+        title: proposal title
+        description: proposal description
+        reward_weight (Dec): new proposed tax rate
+    """
 
     type = "treasury/RewardWeightUpdateProposal"
+    """"""
 
     title: str = attr.ib()
     description: str = attr.ib()
